# Typers Terminal

Typers Terminal is a productivity application used to speed read and type text from any URL, clipboard or builtin drill.  

To learn content faster, a combination of speed reading and typing can be used. There are many studies showing the benefits of reading and taking hand written notes. Hand writing notes is slow at 13-20 while typing is much faster at 40 wpm and can easily be improved to 75wpm+. Though typing is not the same as note taking, I would argue there are still overlapping benefits such as, an increase in ability to focus, conprehension, memory and many more.  

There is nothing stopping you from typing content in a notepad to take notes, but if you type incorrectly, take a microbreak, or scroll pages then you will have to spend time finding your place. Additionally, Stats are collected to show what type of words you struggle with and exercises are provided.  


### Working Features

- Typing Text
    - Drills
        - Customize
            - word amount
            - starting letters
        - Digraphs
            - 2 most frequent charcters
        - Trigraphs
            - 3 most frequent characters
        - Words
            - 300 most common (10fastfingers words)
            - 10,000 words
    - Submit Text
        - URL
            - Selects Header Text and paragraphs, list underneath
        - Clipboard
    - Stats
        - during typing
            - shows wpm for a given word as if you typed that word for 1 min
        - after typing
            - shows
                - average wpm
                - accuracy
                - fastest words
                - slowest words
                - slowest correct words
        
### In Development

- Speed reading
- logging stats
- documentation
    - how to install
    - better annotation
- testing
    - CI/CD tool

### Installation Guide

### How To Use

- start application with `python3 main.py` in `/typers_terminal/typers_terminal`
- navigate with with arrow keys or jk and select with enter
- for typing
    - if a weird symbol that you cannot type is found type ``
    - to exit out early press `esc`
    - force close with `ctrl+c`

### Contribution Instructions

- this
